@@ -8,7 +8,7 @@ class pip_tests(TestCase):
     def test_install(self):
         task = Task()
         task.assert_that(Package('python-virtualenv'), installed())
-        task.command('rm dist/*')
+        task.command('rm dist/*', expected=None)
         task.command('python setup.py sdist')
         task.command('virtualenv --clear venv')
         task.command('. venv/bin/activate; pip install dist/prego*; echo y | pip uninstall prego; deactivate', timeout=50)
